%define anolis_release 2
%bcond_without tests

Name:           python-aiohttp
Version:        3.8.4
Release:        %{anolis_release}%{?dist}
Summary:        Python HTTP client/server for asyncio

License:        Apache-2.0
URL:            https://github.com/aio-libs/aiohttp
# We use requirements/*.txt to generate test dependencies; these files are not
# present in the PyPI sdist, so we must use the GitHub archive.
Source0:        %{url}/archive/v%{version}/aiohttp-%{version}.tar.gz

# downstream only patch
Patch:          0001-Unbundle-llhttp.patch
# [3.8] Make the 3.10 related xfails non-strict
# https://github.com/aio-libs/aiohttp/pull/7178
Patch:          %{url}/pull/7178.patch

BuildRequires:  gcc

BuildRequires:  llhttp-devel

BuildRequires:  python3-devel
BuildRequires:  python3dist(cython)

%global common_description %{expand:
Python HTTP client/server for asyncio which supports both the client and the
server side of the HTTP protocol, client and server websocket, and webservers
with middlewares and pluggable routing.}

%description %{common_description}

%package -n python3-aiohttp
Summary:        %{summary}

Recommends:     python3-aiohttp+speedups

%description -n python3-aiohttp %{common_description}

%pyproject_extras_subpkg -n python3-aiohttp speedups

%prep
%autosetup -p 1 -n aiohttp-%{version}
# Remove bundled llhttp
rm -rvf vendor/llhttp
# Disable test coverage reports
sed -r -i '/--cov=/d' setup.cfg
# We don’t use %%tox because it just runs pytest with coverage analysis; rather
# than patching out the coverage invocation, we can run pytest directly. Still,
# it is useful to generate test dependencies from tox.ini.
# Upstream supports both brotlipy and Brotli, in theory; we have the latter.
sed -r -i \
    -e 's/^[[:blank:]]*coverage$/# &/' \
    -e 's/^[[:blank:]]*-e[[:blank:]]+\.$/# &/' \
    -e 's/brotlipy/Brotli/' \
    tox.ini
# Unpin dependency versions in requirements files, so we can use them to
# generate additional dependencies. Comment out a few optional test
# dependencies that are not yet packaged, as well as coverage dependencies.
sed -r -i \
   -e 's/==[^#;]+//' \
   -e 's/^(proxy[-\.]py|python-on-whales|wait-for-it)/# &/' \
   -e 's/^(coverage|pytest-cov|mypy)/# &/' \
   -e 's/^(setuptools-git)/# &/' \
   requirements/*.txt
# Remove files generated by Cython to regenerate them
grep -rl '/\* Generated by Cython' | xargs -r rm -v

%generate_buildrequires
%{pyproject_buildrequires \
    requirements/base.txt %{?with_tests:requirements/test.txt -t}}

%build
# Recreate removed Cython files using commands extracted from the Makefile.
# We don't run make directly, as it pip-installs Cython.
#
# We don't need a real git checkout, but we do need a .git directory to help
# certain scripts find the root of the source tree.
mkdir -p .git
# See the aiohttp/_find_header.c target in the Makefile; this also generates
# _headers.pyi.
%{python3} tools/gen.py
# Now we can invoke Cython.
%{python3} -m cython -3 aiohttp/*.pyx -I aiohttp
# Now we need to remove the .git directory again, because its presence will
# lead the actual build astray, something like:
#   Install submodules when building from git clone
#   Hint:
#     git submodule update --init
rm -rvf .git
# Now we can actually proceed with building the package.
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files aiohttp

%check
%if %{with tests}
# Fixes problems importing compiled extensions from subprocesses.
export PYTHONSAFEPATH=1
# Setting PYTHONSAFEPATH works only for Python 3.11+, so we must skip any
# affected tests on older Pythons.
%if v"%{python3_version}" < v"3.11"
k="${k-}${k+ and }not test_no_warnings"
%endif
# test_proxy_functional.py requires python3dist(proxy-py)
ignore="${ignore-} --ignore=tests/test_proxy_functional.py"
# test_client_session_timeout_zero requires DNS
k="${k-}${k+ and }not test_client_session_timeout_zero"
# Unexplained flaky error during teardown:
# E               RuntimeError: Event loop is closed
k="${k-}${k+ and }not test_static_file_if_match"
k="${k-}${k+ and }not test_static_file_if_none_match"
%pytest ${ignore-} -k "${k-}"
%else
%pyproject_check_import -e aiohttp.pytest_plugin
%endif

%files -n python3-aiohttp -f %{pyproject_files}

%changelog
* Sun May 07 2023 Funda Wang <fundawang@yeah.net> - 3.8.4-2
- Build with tests

* Sun Apr 30 2023 Funda Wang <fundawang@yeah.net> - 3.8.4-1
- Import package for anolis 23
